.. currentmodule:: sardana.pool.poolmotorgroup

:mod:`~sardana.pool.poolmotorgroup`
=========================================

.. automodule:: sardana.pool.poolmotorgroup

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolMotorGroup`


PoolMotorGroup
-------------------

.. inheritance-diagram:: PoolMotorGroup
    :parts: 1
    
.. autoclass:: PoolMotorGroup
    :show-inheritance:
    :members:
    :undoc-members:

